// File: SumFile.java
// Sum numeric values on each line and all numeric values in any file.
//      The output file contains one double per line,
//       the sum of the corresponding line of the input file.
//      The last line of the output file (sums.data) contains the sum
//       of all the values in the input file.
// Here the file input is done by wrapping a FileReader with a
// StreamTokenizer. This gives us the nextToken() method to permit
// input of the file one token at a time. We also now are able to discern 
// EOL in a file and to ignore non-numeric tokens.

import java.io.*;
import java.util.*;

/**
 * @com.register ( clsid=B9E3A525-0EF4-11D4-8607-00A0CC5FD79C, typelib=B9E3A524-0EF4-11D4-8607-00A0CC5FD79C )
 */
public class SumFile {

// Read a line from the input file and Sum the ints.
// StringTokenizer allows each token on the line to be extracted.
//      Note that all tokens are strings and are then converted (see
//      the use of the Integer class to accomplish this)       
public static double SumLine(StreamTokenizer Data) throws java.io.IOException
{double Sum=0;
 Data.nextToken(); 
 while (Data.ttype!=Data.TT_EOF && Data.ttype!=Data.TT_EOL) {
	 if (Data.ttype==Data.TT_NUMBER) 
	   Sum+=Data.nval;
     Data.nextToken();
 }
 return(Sum);
}

public static void main(String[] args) throws java.io.IOException
{double SumOfLine,SumOfFile=0.0;
 // Associate the disk file with the File object
 System.out.println("Files in the present Directory:");
 FileOpener.showLoggedDir();
 File InputFile=new File(FileOpener.GetInputFile());
 // if file doesn't exist, stop
 if (!InputFile.exists()) {
	 System.out.println(InputFile.getName()+" not found");
	 return;
 }
 // Now, open a stream from the input file; 
 //				Need a StreamTokenizer to handle input
 StreamTokenizer DataInput=
                         new StreamTokenizer(new FileReader(InputFile));
 File OutputFile=new File(FileOpener.getOutputFile());
 PrintWriter DataOutput=
                      new PrintWriter(new FileWriter(OutputFile));
 // Set the StreamTokenizer to recognize EOL
 DataInput.eolIsSignificant(true);
 // Read the file and process it
 String OutStr;
 while (DataInput.ttype!=DataInput.TT_EOF) {
  SumOfLine=SumLine(DataInput);
  OutStr=String.valueOf(SumOfLine);
  DataOutput.println(OutStr);
  DataOutput.flush();
  SumOfFile+=SumOfLine;
 }
 OutStr=String.valueOf(SumOfFile);
 DataOutput.println(OutStr);
 DataOutput.flush();
}


}

